@@ -27,80 +27,82 @@
 #include "fadingnavigationwidget.h"
 
 class QGraphicsLinearLayout;
+class QDBusPendingCallWatcher;
 
 namespace Plasma
 {
 #if (PLASMA_VERSION_MAJOR < 3)
-	class Icon;
-#else 
-	class IconWidget;
+    class Icon;
+#else
+    class IconWidget;
 #endif
-	class Label;
+    class Label;
 }
 
 
 namespace ktplasma
 {
-	class ChunkBar;
+    class ChunkBar;
 
-	/**
-		Plasma applet for ktorrent
-	*/	
-	class Applet : public Plasma::PopupApplet
-	{
-		Q_OBJECT
+    /**
+        Plasma applet for ktorrent
+    */
+    class Applet : public Plasma::PopupApplet
+    {
+        Q_OBJECT
 
-	public:
-		Applet(QObject *parent, const QVariantList &args);
-		virtual ~Applet();
-		
-		virtual void init();
-		virtual void createConfigurationInterface(KConfigDialog *parent);
-		virtual void saveState(KConfigGroup & config) const;
-		virtual QGraphicsWidget *graphicsWidget();
-		virtual void constraintsEvent(Plasma::Constraints constraints);
+    public:
+        Applet(QObject* parent, const QVariantList& args);
+        virtual ~Applet();
 
-	private slots:
-		void dataUpdated(const QString &name,const Plasma::DataEngine::Data &data);
-		void configUpdated();
-		void sourceAdded(const QString & s);
-		void sourceRemoved(const QString & s);
-		void iconClicked();
-		void selectPrev();
-		void selectNext();
-		
-	private:
-		void updateTorrentCombo();
-		void updateCurrent(const Plasma::DataEngine::Data &data);
-		void setSource(QString source);
-		void initSource();
-		void clearData();
-		void updateSources();
-		void updateConnection(bool connected);
-		void updateNavigation();
+        virtual void init();
+        virtual void createConfigurationInterface(KConfigDialog* parent);
+        virtual void saveState(KConfigGroup& config) const;
+        virtual QGraphicsWidget* graphicsWidget();
+        virtual void constraintsEvent(Plasma::Constraints constraints);
 
-	private:
-		Ui_AppletConfig ui;
-		QGraphicsWidget* desktop_widget;
-		QGraphicsLinearLayout* root_layout;
+    private slots:
+        void dataUpdated(const QString& name, const Plasma::DataEngine::Data& data);
+        void configUpdated();
+        void sourceAdded(const QString& s);
+        void sourceRemoved(const QString& s);
+        void iconClicked();
+        void selectPrev();
+        void selectNext();
+        void dbusCallFinished(QDBusPendingCallWatcher* self);
+
+    private:
+        void updateTorrentCombo();
+        void updateCurrent(const Plasma::DataEngine::Data& data);
+        void setSource(QString source);
+        void initSource();
+        void clearData();
+        void updateSources();
+        void updateConnection(bool connected);
+        void updateNavigation();
+
+    private:
+        Ui_AppletConfig ui;
+        QGraphicsWidget* desktop_widget;
+        QGraphicsLinearLayout* root_layout;
 #if (PLASMA_VERSION_MAJOR < 3)
-		Plasma::Icon* icon;
-#else 
-		Plasma::IconWidget* icon;
+        Plasma::Icon* icon;
+#else
+        Plasma::IconWidget* icon;
 #endif
-		Plasma::Label* title;
-		Plasma::Label* misc;
-		ChunkBar* chunk_bar;
-		FadingNavigationWidget *navigation;
-	
-		Plasma::DataEngine* engine;
-		bool connected_to_app;
-		QString current_source;
-		QStringList sources;
-	};
+        Plasma::Label* title;
+        Plasma::Label* misc;
+        ChunkBar* chunk_bar;
+        FadingNavigationWidget* navigation;
+
+        Plasma::DataEngine* engine;
+        bool connected_to_app;
+        QString current_source;
+        QStringList sources;
+    };
 
 }
- 
+
 
 
 #endif
