@@ -26,31 +26,39 @@
 
 namespace kt
 {
-	struct ScheduleItem;
+    struct ScheduleItem;
+    class Schedule;
 
-	/**
-		@author
-	*/
-	class EditItemDlg : public KDialog, public Ui_EditItemDlg
-	{
-		Q_OBJECT
-	public:		
-		EditItemDlg(QWidget* parent);
-		virtual ~EditItemDlg();
-		
-		/**
-		 * Execute the dialog
-		 * @param item The item to fill in if the user presses OK
-		 * @return true if OK was pressed
-		 */
-		bool execute(ScheduleItem* item);
+    /**
+        @author
+    */
+    class EditItemDlg : public KDialog, public Ui_EditItemDlg
+    {
+        Q_OBJECT
+    public:
+        EditItemDlg(Schedule* schedule, ScheduleItem* item, bool new_item, QWidget* parent);
+        virtual ~EditItemDlg();
 
-	private slots:
-		void fromChanged(const QTime & time);
-		void toChanged(const QTime & time);
-		void pausedChanged(bool on);
-		void screensaverLimitsToggled(bool on);
-	};
+        /**
+         * accept will only work if the item does not conflict
+         **/
+        virtual void accept();
+
+    private slots:
+        void fromChanged(const QTime& time);
+        void toChanged(const QTime& time);
+        void startDayChanged(int idx);
+        void endDayChanged(int idx);
+        void suspendedChanged(bool on);
+        void screensaverLimitsToggled(bool on);
+
+    private:
+        void fillItem();
+
+    private:
+        Schedule* schedule;
+        ScheduleItem* item;
+    };
 
 }
 
