@@ -21,29 +21,29 @@
 #ifndef KT_ADDTRACKERSDIALOG_H
 #define KT_ADDTRACKERSDIALOG_H
 
-#include <KDialog>
+#include <QDialog>
 #include <KEditListWidget>
 
 
 namespace kt
 {
 
-	/**
-	 * Dialog to add trackers
-	 */
-	class AddTrackersDialog : public KDialog
-	{
-		Q_OBJECT
-	public:
-		AddTrackersDialog(QWidget* parent, const QStringList & tracker_hints);
-		virtual ~AddTrackersDialog();
-		
-		/// Get the tracker list
-		QStringList trackerList() const;
-		
-	private:
-		KEditListWidget* trackers;
-	};
+    /**
+     * Dialog to add trackers
+     */
+    class AddTrackersDialog : public QDialog
+    {
+        Q_OBJECT
+    public:
+        AddTrackersDialog(QWidget* parent, const QStringList& tracker_hints);
+        virtual ~AddTrackersDialog();
+
+        /// Get the tracker list
+        QStringList trackerList() const;
+
+    private:
+        KEditListWidget* trackers;
+    };
 
 }
 
