@@ -1,8 +1,8 @@
 /***************************************************************************
  *   Copyright (C) 2006-2007 by Joris Guisson, Ivan Vasic                  *
  *   joris.guisson@gmail.com                                               *
- *	 ivasic@gmail.com                                                  *
- *									   *
+ *   ivasic@gmail.com                                                  *
+ *                                     *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -22,44 +22,47 @@
 #define TRACKERVIEW_H
 
 #include "ui_trackerview.h"
+#include <ksharedconfig.h>
 #include <QSortFilterProxyModel>
 #include <interfaces/torrentinterface.h>
 
 namespace kt
 {
-	class TrackerModel;
+    class TrackerModel;
 
-	/**
-	 * @author Ivan Vasic <ivan@ktorrent.org>
-	 */
-	class TrackerView: public QWidget, public Ui_TrackerView
-	{
-		Q_OBJECT
-	public:
-		TrackerView(QWidget *parent);
-		virtual ~TrackerView();
-			
-		void update();
-		void changeTC(bt::TorrentInterface* ti);
-		void saveState(KSharedConfigPtr cfg);
-		void loadState(KSharedConfigPtr cfg);
-			
-	public slots:
-		virtual void updateClicked();
-		virtual void restoreClicked();
-		virtual void changeClicked();
-		virtual void removeClicked();
-		virtual void addClicked();        
-		virtual void scrapeClicked();
-		void currentChanged(const QModelIndex & current,const QModelIndex & previous);
-			
-	private:
-		void torrentChanged(bt::TorrentInterface* ti);
-			
-	private:
-		bt::TorrentInterface::WPtr tc;
-		TrackerModel* model;
-		QSortFilterProxyModel* proxy_model;
-	};
+    /**
+     * @author Ivan Vasic <ivan@ktorrent.org>
+     */
+    class TrackerView: public QWidget, public Ui_TrackerView
+    {
+        Q_OBJECT
+    public:
+        TrackerView(QWidget* parent);
+        virtual ~TrackerView();
+
+        void update();
+        void changeTC(bt::TorrentInterface* ti);
+        void saveState(KSharedConfigPtr cfg);
+        void loadState(KSharedConfigPtr cfg);
+
+    public slots:
+        virtual void updateClicked();
+        virtual void restoreClicked();
+        virtual void changeClicked();
+        virtual void removeClicked();
+        virtual void addClicked();
+        virtual void scrapeClicked();
+        void currentChanged(const QModelIndex& current, const QModelIndex& previous);
+
+    private:
+        void torrentChanged(bt::TorrentInterface* ti);
+
+    private:
+        bt::TorrentInterface::WPtr tc;
+        TrackerModel* model;
+        QSortFilterProxyModel* proxy_model;
+        QStringList tracker_hints;
+        bool header_state_loaded;
+    };
 }
 #endif
