@@ -25,53 +25,57 @@
 
 namespace kt
 {
-	class ConvertDialog;
-	
-	/**
-		Job to download and convert a filter file
-	*/
-	class DownloadAndConvertJob : public KIO::Job
-	{
-		Q_OBJECT
-	public:
-		enum Mode
-		{
-			Verbose,Quietly
-		};
-		DownloadAndConvertJob(const KUrl & url,Mode mode);
-		virtual ~DownloadAndConvertJob();
-		
-		enum ErrorCode
-		{
-			CANCELED = 100,DOWNLOAD_FAILED,UNZIP_FAILED,MOVE_FAILED,BACKUP_FAILED
-		};
-		
-		virtual void kill(KJob::KillVerbosity v);
-		void start();
-		
-		bool isAutoUpdate() const {return mode == Quietly;}
-		
-	private slots:
-		void downloadFileFinished(KJob*);
-		void convert(KJob*);
-		void extract(KJob*);
-		void makeBackupFinished(KJob* );
-		void revertBackupFinished(KJob*);
-		void convertAccepted();
-		void convertRejected();
-			
-	private:
-		void convert();
-		void cleanUp(const QString & path);
-		void cleanUpFiles();
-		
-	private:
-		KUrl url;
-		KJob* active_job;
-		bool unzip;
-		ConvertDialog* convert_dlg;
-		Mode mode;
-	};
+    class ConvertDialog;
+
+    /**
+        Job to download and convert a filter file
+    */
+    class DownloadAndConvertJob : public KIO::Job
+    {
+        Q_OBJECT
+    public:
+        enum Mode
+        {
+            Verbose, Quietly
+        };
+        DownloadAndConvertJob(const QUrl& url, Mode mode);
+        virtual ~DownloadAndConvertJob();
+
+        enum ErrorCode
+        {
+            CANCELED = 100, DOWNLOAD_FAILED, UNZIP_FAILED, MOVE_FAILED, BACKUP_FAILED
+        };
+
+        virtual void kill(KJob::KillVerbosity v);
+        void start();
+
+        bool isAutoUpdate() const {return mode == Quietly;}
+
+    signals:
+        /// Emitted when the job needs to show a notification
+        void notification(const QString& msg);
+
+    private slots:
+        void downloadFileFinished(KJob*);
+        void convert(KJob*);
+        void extract(KJob*);
+        void makeBackupFinished(KJob*);
+        void revertBackupFinished(KJob*);
+        void convertAccepted();
+        void convertRejected();
+
+    private:
+        void convert();
+        void cleanUp(const QString& path);
+        void cleanUpFiles();
+
+    private:
+        QUrl url;
+        KJob* active_job;
+        bool unzip;
+        ConvertDialog* convert_dlg;
+        Mode mode;
+    };
 
 }
 
