@@ -22,54 +22,67 @@
 #define KTSCRIPTMANAGER_H
 
 #include <QListView>
+#include <interfaces/activity.h>
 
-class KToolBar;
-class KMenu;
+class QAction;
 class KActionCollection;
 
 namespace Kross
 {
-	class Action;
+    class Action;
 }
 
 namespace kt
 {
-	class ScriptModel;
+    class Script;
+    class ScriptModel;
 
-	/**
-		Widget to display all scripts.
-	*/
-	class ScriptManager : public QWidget
-	{
-		Q_OBJECT
-	public:
-		ScriptManager(ScriptModel* model,KActionCollection* ac,QWidget* parent);
-		virtual ~ScriptManager();
-		
-		/// Get all selected scripts
-		QModelIndexList selectedScripts();
-		
-		/// Update all actions and make sure they are properly enabled or disabled
-		void updateActions(const QModelIndexList & selected);
-		
-	private slots:
-		void onSelectionChanged(const QItemSelection & selected,const QItemSelection & deselected);
-		void showContextMenu(const QPoint& p);
-		void dataChanged(const QModelIndex & f,const QModelIndex & to);
-		
-	signals:
-		void enableRemoveScript(bool on);
-		void enableRunScript(bool on);
-		void enableStopScript(bool on);
-		void enableProperties(bool on);
-		void enableConfigure(bool on);
-		
-	private:
-		ScriptModel* model;
-		QListView* view;
-		KToolBar* toolbar;
-		KMenu* context_menu;
-	};
+    /**
+        Widget to display all scripts.
+    */
+    class ScriptManager : public Activity
+    {
+        Q_OBJECT
+    public:
+        ScriptManager(ScriptModel* model, QWidget* parent);
+        virtual ~ScriptManager();
+
+        /// Get all selected scripts
+        QModelIndexList selectedScripts();
+
+        /// Update all actions and make sure they are properly enabled or disabled
+        void updateActions(const QModelIndexList& selected);
+
+    private slots:
+        void onSelectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
+        void showContextMenu(const QPoint& p);
+        void dataChanged(const QModelIndex& f, const QModelIndex& to);
+        void runScript();
+        void stopScript();
+        void editScript();
+        void showProperties();
+        void showProperties(Script* script);
+        void configureScript();
+
+    private:
+        void setupActions();
+
+    signals:
+        void addScript();
+        void removeScript();
+
+    private:
+        ScriptModel* model;
+        QListView* view;
+
+        QAction * add_script;
+        QAction * remove_script;
+        QAction * run_script;
+        QAction * stop_script;
+        QAction * edit_script;
+        QAction * properties;
+        QAction * configure_script;
+    };
 
 }
 
