@@ -27,47 +27,35 @@
 
 namespace kt
 {
-	class SearchPrefPage;
-	class SearchToolBar;
-	class SearchActivity;
+    class SearchPrefPage;
+    class SearchActivity;
 
-	/**
-	@author Joris Guisson
-	*/
-	class SearchPlugin : public Plugin
-	{
-		Q_OBJECT
-	public:
-		SearchPlugin(QObject* parent, const QStringList& args);
-		virtual ~SearchPlugin();
+    /**
+    @author Joris Guisson
+    */
+    class SearchPlugin : public Plugin
+    {
+        Q_OBJECT
+    public:
+        SearchPlugin(QObject* parent, const QVariantList& args);
+        virtual ~SearchPlugin();
 
-		virtual void load();
-		virtual void unload();
-		virtual bool versionCheck(const QString& version) const;
-		
-		SearchEngineList* getSearchEngineList() const {return engines;}
-		KAction* getBackAction() {return back_action;}
-		int currentSearchEngine() const;
-	private slots:
-		void search(const QString & text,int engine,bool external);
-		void preferencesUpdated();
+        virtual void load();
+        virtual void unload();
+        virtual bool versionCheck(const QString& version) const;
 
-	private:
-		void setupActions();
-		
-	private:
-		SearchActivity* activity;
-		SearchPrefPage* pref;
-		SearchToolBar* toolbar;
-		SearchEngineList* engines;
-		
-		KAction* find_action;
-		KAction* back_action;
-		KAction* reload_action;
-		KAction* search_action;
-		KAction* copy_action;
-		KAction* home_action;
-	};
+        SearchEngineList* getSearchEngineList() const {return engines;}
+        SearchActivity* getSearchActivity() const {return activity;}
+
+    private slots:
+        void search(const QString& text, int engine, bool external);
+        void preferencesUpdated();
+
+    private:
+        SearchActivity* activity;
+        SearchPrefPage* pref;
+        SearchEngineList* engines;
+    };
 
 }
 
