@@ -30,47 +30,49 @@ class KActionCollection;
 
 namespace kt
 {
-	class SearchEngineList;
+    class SearchEngineList;
 
-	/**
-		Holds all widgets of the toolbar of the search plugin.
-	*/
-	class SearchToolBar : public QObject
-	{
-		Q_OBJECT
-	
-	public:
-		SearchToolBar(KActionCollection* ac,SearchEngineList* sl,QObject* parent);
-		virtual ~SearchToolBar();
-		
-		/// Save settings like current search engine
-		void saveSettings();
-		
-		/// Get the index of the current search engine
-		int currentSearchEngine() const;
+    /**
+        Holds all widgets of the toolbar of the search plugin.
+    */
+    class SearchToolBar : public QObject
+    {
+        Q_OBJECT
 
-	public slots:
-		/// Clear the search history
-		void clearHistory();
-			
-	protected slots:
-		void searchNewTabPressed();
-		void searchBoxReturn();
-		void textChanged(const QString & str);
-		
-	signals:
-		/// Emitted when the user presses enter or clicks search
-		void search(const QString & text,int engine,bool external);
-		
-	private:
-		void loadSearchHistory();
-		void saveSearchHistory();
-	
-	private:
-		KComboBox* m_search_text;
-		KComboBox* m_search_engine;
-		QAction* m_search_new_tab;
-	};
+    public:
+        SearchToolBar(KActionCollection* ac, SearchEngineList* sl, QObject* parent);
+        virtual ~SearchToolBar();
+
+        /// Save settings like current search engine
+        void saveSettings();
+
+        /// Get the index of the current search engine
+        int currentSearchEngine() const;
+
+    public slots:
+        /// Clear the search history
+        void clearHistory();
+
+    protected slots:
+        void searchNewTabPressed();
+        void searchBoxReturn();
+        void textChanged(const QString& str);
+        void selectedEngineChanged(int idx);
+
+    signals:
+        /// Emitted when the user presses enter or clicks search
+        void search(const QString& text, int engine, bool external);
+
+    private:
+        void loadSearchHistory();
+        void saveSearchHistory();
+
+    private:
+        KComboBox* m_search_text;
+        KComboBox* m_search_engine;
+        QAction* m_search_new_tab;
+        int m_current_search_engine;
+    };
 }
 
 #endif
