@@ -17,76 +17,73 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <kgenericfactory.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kstdaction.h>
+#include "upnpplugin.h"
+
+#include <QStandardPaths>
+#include <kpluginfactory.h>
+#include <klocalizedstring.h>
 #include <interfaces/guiinterface.h>
 #include <util/fileops.h>
 #include <util/log.h>
 #include <util/logsystemmanager.h>
 #include <upnp/upnpmcastsocket.h>
-#include "upnpplugin.h"
+
 #include "upnpwidget.h"
 #include <interfaces/torrentactivityinterface.h>
 
-
-K_EXPORT_COMPONENT_FACTORY(ktupnpplugin,KGenericFactory<kt::UPnPPlugin>("ktupnpplugin"))
+K_PLUGIN_FACTORY_WITH_JSON(ktorrent_upnp, "ktorrent_upnp.json", registerPlugin<kt::UPnPPlugin>();)
 
 using namespace bt;
 
 namespace kt
 {
 
-	UPnPPlugin::UPnPPlugin(QObject* parent, const QStringList& /*args*/) : Plugin(parent)
-	{
-		sock = 0;
-		upnp_tab = 0;
-	}
+    UPnPPlugin::UPnPPlugin(QObject* parent, const QVariantList& /*args*/) : Plugin(parent), sock(0), upnp_tab(0)
+    {
+    }
 
 
-	UPnPPlugin::~UPnPPlugin()
-	{
-	}
+    UPnPPlugin::~UPnPPlugin()
+    {
+    }
 
 
-	void UPnPPlugin::load()
-	{
-		LogSystemManager::instance().registerSystem(i18n("UPnP"),SYS_PNP);
-		sock = new UPnPMCastSocket();
-		upnp_tab = new UPnPWidget(sock,0);
-		GUIInterface* gui = getGUI();
-		gui->getTorrentActivity()->addToolWidget(upnp_tab,i18n("UPnP"),"kt-upnp",
-			   i18n("Shows the status of the UPnP plugin"));
-		// load the routers list
-		QString routers_file = KGlobal::dirs()->saveLocation("data","ktorrent") + "routers";
-		if (bt::Exists(routers_file))
-			sock->loadRouters(routers_file);
-		sock->discover();
-	}
+    void UPnPPlugin::load()
+    {
+        LogSystemManager::instance().registerSystem(i18n("UPnP"), SYS_PNP);
+        sock = new UPnPMCastSocket();
+        upnp_tab = new UPnPWidget(sock, 0);
+        GUIInterface* gui = getGUI();
+        gui->getTorrentActivity()->addToolWidget(upnp_tab, i18n("UPnP"), QLatin1String("kt-upnp"),
+                i18n("Shows the status of the UPnP plugin"));
+        // load the routers list
+        QString routers_file = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("routers"));
+        if (routers_file.length())
+            sock->loadRouters(routers_file);
+        sock->discover();
+    }
 
-	void UPnPPlugin::unload()
-	{
-		LogSystemManager::instance().unregisterSystem(i18n("UPnP"));
-		QString routers_file = KGlobal::dirs()->saveLocation("data","ktorrent") + "routers";
-		sock->saveRouters(routers_file);
-		getGUI()->getTorrentActivity()->removeToolWidget(upnp_tab);
-		sock->close();
-		delete upnp_tab;
-		upnp_tab = 0;
-		delete sock;
-		sock = 0;
-	}
-	
-	void UPnPPlugin::shutdown(bt::WaitJob* job)
-	{
-		upnp_tab->shutdown(job);
-	}
-	
-	bool UPnPPlugin::versionCheck(const QString & version) const
-	{
-		return version == KT_VERSION_MACRO;
-	}
+    void UPnPPlugin::unload()
+    {
+        LogSystemManager::instance().unregisterSystem(i18n("UPnP"));
+        QString routers_file = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/routers");
+        sock->saveRouters(routers_file);
+        getGUI()->getTorrentActivity()->removeToolWidget(upnp_tab);
+        sock->close();
+        delete upnp_tab;
+        upnp_tab = 0;
+        delete sock;
+        sock = 0;
+    }
+
+    void UPnPPlugin::shutdown(bt::WaitJob* job)
+    {
+        upnp_tab->shutdown(job);
+    }
+
+    bool UPnPPlugin::versionCheck(const QString& version) const
+    {
+        return version == KT_VERSION_MACRO;
+    }
 }
 #include "upnpplugin.moc"
